@@ -4,7 +4,7 @@
     <message>
         <location filename="../view/widget/closeconfirmdialog.cpp" line="61"/>
         <source>Please select your operation</source>
-        <translation type="unfinished"/>
+        <translation>Valitse toiminto</translation>
     </message>
     <message>
         <location filename="../view/widget/closeconfirmdialog.cpp" line="68"/>
@@ -14,12 +14,12 @@
     <message>
         <location filename="../view/widget/closeconfirmdialog.cpp" line="70"/>
         <source>Minimize to system tray</source>
-        <translation type="unfinished"/>
+        <translation>Minimoi valikkoon</translation>
     </message>
     <message>
         <location filename="../view/widget/closeconfirmdialog.cpp" line="79"/>
-        <source>Never ask again</source>
-        <translation type="unfinished"/>
+        <source>Do not ask again</source>
+        <translation>Älä kysy uudestaan</translation>
     </message>
     <message>
         <location filename="../view/widget/closeconfirmdialog.cpp" line="90"/>
@@ -52,17 +52,17 @@
     <message>
         <location filename="../view/footerwidget.cpp" line="293"/>
         <source>Favorite</source>
-        <translation type="unfinished"/>
+        <translation>Suosikki</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="294"/>
         <source>Lyrics</source>
-        <translation>Laulun sanat</translation>
+        <translation>Sanat</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="239"/>
         <source>Unknown Title</source>
-        <translation type="unfinished"/>
+        <translation>Tuntematon nimi</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="245"/>
@@ -74,7 +74,7 @@
     <message>
         <location filename="../view/footerwidget.cpp" line="295"/>
         <source>Play Mode</source>
-        <translation type="unfinished"/>
+        <translation>Toistotila</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="296"/>
@@ -84,17 +84,17 @@
     <message>
         <location filename="../view/footerwidget.cpp" line="696"/>
         <source>List Loop</source>
-        <translation type="unfinished"/>
+        <translation>Musiikkilistan silmukka</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="699"/>
         <source>Single Loop</source>
-        <translation type="unfinished"/>
+        <translation>Silmukka</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="702"/>
         <source>Shuffle</source>
-        <translation type="unfinished"/>
+        <translation>Sekoitta</translation>
     </message>
 </context>
 <context>
@@ -114,12 +114,12 @@
         <location filename="../view/importwidget.cpp" line="80"/>
         <location filename="../view/importwidget.cpp" line="121"/>
         <source>%1 music directory or drag &amp; drop music file to add music</source>
-        <translation type="unfinished"/>
+        <translation>%1 musiikkikansio lisää musiikkia vetämällä tai pudottamalla</translation>
     </message>
     <message>
         <location filename="../view/importwidget.cpp" line="112"/>
         <source>Loading music, please wait...</source>
-        <translation type="unfinished"/>
+        <translation>Lataa musiikkia, odota ...</translation>
     </message>
 </context>
 <context>
@@ -137,7 +137,7 @@
     <message>
         <location filename="../view/widget/infodialog.cpp" line="118"/>
         <source>Album:</source>
-        <translation type="unfinished"/>
+        <translation>Albumi:</translation>
     </message>
     <message>
         <location filename="../view/widget/infodialog.cpp" line="118"/>
@@ -167,7 +167,7 @@
     <message>
         <location filename="../view/widget/infodialog.cpp" line="119"/>
         <source>Duration:</source>
-        <translation type="unfinished"/>
+        <translation>Kesto:</translation>
     </message>
 </context>
 <context>
@@ -175,15 +175,15 @@
     <message>
         <location filename="../view/loadwidget.cpp" line="43"/>
         <source>Loading...</source>
-        <translation type="unfinished"/>
+        <translation>Lataa...</translation>
     </message>
 </context>
 <context>
     <name>LyricWidget</name>
     <message>
         <location filename="../view/lyricwidget.cpp" line="166"/>
-        <source>Search lyrics</source>
-        <translation type="unfinished"/>
+        <source>Find lyrics</source>
+        <translation>Etsi sanoitukset</translation>
     </message>
     <message>
         <location filename="../view/lyricwidget.cpp" line="170"/>
@@ -209,79 +209,79 @@
 <context>
     <name>MainFrame</name>
     <message>
-        <location filename="../view/mainframe.cpp" line="135"/>
+        <location filename="../view/mainframe.cpp" line="136"/>
         <source>New playlist</source>
-        <translation type="unfinished"/>
+        <translation>Uusi soittolista</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="151"/>
+        <location filename="../view/mainframe.cpp" line="152"/>
         <source>Settings</source>
         <translation>Asetukset</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="253"/>
-        <source>Deepin Music Player is a local  music player with beautiful design and simple functions. It supports viewing lyrics when playing, playing lossless music and customize playlist, etc.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/mainframe.cpp" line="182"/>
-        <location filename="../view/mainframe.cpp" line="578"/>
+        <location filename="../view/mainframe.cpp" line="183"/>
+        <location filename="../view/mainframe.cpp" line="595"/>
         <source>Exit</source>
         <translation>Poistu</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="141"/>
+        <location filename="../view/mainframe.cpp" line="142"/>
         <source>Add folder</source>
         <translation>Lisää kansio</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="146"/>
+        <location filename="../view/mainframe.cpp" line="147"/>
         <source>Add file</source>
         <translation>Lisää tiedosto</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="167"/>
+        <location filename="../view/mainframe.cpp" line="168"/>
         <source>Dark theme</source>
-        <translation type="unfinished"/>
+        <translation>Tumma teema</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="575"/>
+        <location filename="../view/mainframe.cpp" line="254"/>
+        <source>Deepin Music is a beautiful and simple music player that plays local audios. It supports viewing lyrics during playback, playing lossless audio and playlist customization, etc.</source>
+        <translation>Deepin Music on kaunis ja yksinkertainen musiikkisoitin, joka toistaa kiintolevysi paikallista musiikkia. Se tukee sanoitusten näyttämistä toiston aikana, häviöttömän äänen ja soittolistan muokkaamista jne.</translation>
+    </message>
+    <message>
+        <location filename="../view/mainframe.cpp" line="592"/>
         <source>Play/Pause</source>
         <translation>Toista/Keskeytä</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="576"/>
+        <location filename="../view/mainframe.cpp" line="593"/>
         <source>Previous</source>
         <translation>Edellinen</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="722"/>
+        <location filename="../view/mainframe.cpp" line="739"/>
         <source>Invalid or non-existent file</source>
-        <translation type="unfinished"/>
+        <translation>Virheellinen tai olematon tiedosto</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="743"/>
+        <location filename="../view/mainframe.cpp" line="760"/>
         <source>Failed to import, no vaild music file found!</source>
-        <translation type="unfinished"/>
+        <translation>Tuonti epäonnistui, musiikkitiedostoa ei löytynyt!</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="1018"/>
+        <location filename="../view/mainframe.cpp" line="1027"/>
         <source>All music</source>
-        <translation type="unfinished"/>
+        <translation>Kaikki musiikki</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="723"/>
-        <location filename="../view/mainframe.cpp" line="748"/>
+        <location filename="../view/mainframe.cpp" line="740"/>
+        <location filename="../view/mainframe.cpp" line="765"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="673"/>
+        <location filename="../view/mainframe.cpp" line="690"/>
         <source>Successfully added to &quot;%1&quot;</source>
-        <translation type="unfinished"/>
+        <translation>Lisätty onnistuneesti osoitteeseen &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="577"/>
+        <location filename="../view/mainframe.cpp" line="594"/>
         <source>Next</source>
         <translation>Seuraava</translation>
     </message>
@@ -289,70 +289,70 @@
 <context>
     <name>MusicListView</name>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="287"/>
+        <location filename="../view/widget/musiclistview.cpp" line="295"/>
         <source>New playlist</source>
-        <translation type="unfinished"/>
+        <translation>Uusi soittolista</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="327"/>
+        <location filename="../view/widget/musiclistview.cpp" line="335"/>
         <source>Play</source>
         <translation>Toista</translation>
     </message>
-    <message>
-        <location filename="../view/widget/musiclistview.cpp" line="329"/>
-        <source>Add to playlist</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/widget/musiclistview.cpp" line="334"/>
-        <source>Display in file manager</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/widget/musiclistview.cpp" line="361"/>
-        <source>Song info</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <location filename="../view/widget/musiclistview.cpp" line="337"/>
+        <source>Add to playlist</source>
+        <translation>Lisää soittolistaan</translation>
+    </message>
+    <message>
+        <location filename="../view/widget/musiclistview.cpp" line="342"/>
+        <source>Display in file manager</source>
+        <translation>Näytä tiedostonhallinnassa</translation>
+    </message>
+    <message>
+        <location filename="../view/widget/musiclistview.cpp" line="369"/>
+        <source>Song info</source>
+        <translation>Kappaleen tiedot</translation>
+    </message>
+    <message>
+        <location filename="../view/widget/musiclistview.cpp" line="425"/>
+        <source>Are you sure you want to delete %1?</source>
+        <translation>Haluatko varmasti poistaa %1?</translation>
+    </message>
+    <message>
+        <location filename="../view/widget/musiclistview.cpp" line="427"/>
+        <location filename="../view/widget/musiclistview.cpp" line="431"/>
+        <source>Are you sure you want to delete the selected %1 songs?</source>
+        <translation>Haluatko varmasti poistaa valitut %1 kappaleet?</translation>
+    </message>
+    <message>
+        <location filename="../view/widget/musiclistview.cpp" line="345"/>
         <source>Remove from playlist</source>
         <translation>Poista soittolistalta</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="338"/>
+        <location filename="../view/widget/musiclistview.cpp" line="346"/>
         <source>Delete from local disk</source>
-        <translation type="unfinished"/>
+        <translation>Poista paikalliselta levyltä</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="357"/>
+        <location filename="../view/widget/musiclistview.cpp" line="365"/>
         <source>Encoding</source>
         <translation>Tavuesitys</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="407"/>
+        <location filename="../view/widget/musiclistview.cpp" line="415"/>
         <source>Cancel</source>
         <translation>Peruuta</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="408"/>
+        <location filename="../view/widget/musiclistview.cpp" line="416"/>
         <source>Delete</source>
         <translation>Poista</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="417"/>
-        <source>Are you sure to delete %1?</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/widget/musiclistview.cpp" line="419"/>
-        <location filename="../view/widget/musiclistview.cpp" line="423"/>
-        <source>Are you sure to delete the selected %1 songs?</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/widget/musiclistview.cpp" line="424"/>
+        <location filename="../view/widget/musiclistview.cpp" line="432"/>
         <source>Deleting the current song will also delete the song files contained</source>
-        <translation type="unfinished"/>
+        <translation>Nykyisen kappaleen poistaminen poistaa myös lauluun sisältyvät tiedostot</translation>
     </message>
     <message>
         <location filename="../view/widget/delegate/musicitemdelegate.cpp" line="299"/>
@@ -370,12 +370,12 @@
     <message>
         <location filename="../view/musiclistwidget.cpp" line="140"/>
         <source>No Music</source>
-        <translation type="unfinished"/>
+        <translation>Ei musiikkia</translation>
     </message>
     <message>
         <location filename="../view/musiclistwidget.cpp" line="142"/>
         <source>No result found</source>
-        <translation type="unfinished"/>
+        <translation>Tuloksia ei löytynyt</translation>
     </message>
     <message>
         <location filename="../view/musiclistwidget.cpp" line="174"/>
@@ -385,7 +385,7 @@
     <message>
         <location filename="../view/musiclistwidget.cpp" line="182"/>
         <source>Time added</source>
-        <translation type="unfinished"/>
+        <translation>Lisätty aika</translation>
     </message>
     <message>
         <location filename="../view/musiclistwidget.cpp" line="183"/>
@@ -400,7 +400,7 @@
     <message>
         <location filename="../view/musiclistwidget.cpp" line="185"/>
         <source>Album name</source>
-        <translation type="unfinished"/>
+        <translation>Albumin nimi</translation>
     </message>
     <message>
         <location filename="../view/musiclistwidget.cpp" line="217"/>
@@ -411,17 +411,17 @@
 <context>
     <name>PlayListItem</name>
     <message>
-        <location filename="../view/widget/playlistitem.cpp" line="193"/>
+        <location filename="../view/widget/playlistitem.cpp" line="187"/>
+        <source>Are you sure you want to delete this playlist?</source>
+        <translation>Haluatko varmasti poistaa tämän soittolistan?</translation>
+    </message>
+    <message>
+        <location filename="../view/widget/playlistitem.cpp" line="194"/>
         <source>Delete</source>
         <translation>Poista</translation>
     </message>
     <message>
-        <location filename="../view/widget/playlistitem.cpp" line="186"/>
-        <source>Are you sure to delete this playlist?</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/widget/playlistitem.cpp" line="192"/>
+        <location filename="../view/widget/playlistitem.cpp" line="193"/>
         <source>Cancel</source>
         <translation>Peruuta</translation>
     </message>
@@ -452,22 +452,22 @@
     <message>
         <location filename="../core/playlistmanager.cpp" line="79"/>
         <source>New playlist</source>
-        <translation type="unfinished"/>
+        <translation>Uusi soittolista</translation>
     </message>
     <message>
         <location filename="../core/playlistmanager.cpp" line="135"/>
         <source>All Music</source>
-        <translation type="unfinished"/>
+        <translation>Kaikki musiikki</translation>
     </message>
     <message>
         <location filename="../core/playlistmanager.cpp" line="141"/>
         <source>My favorites</source>
-        <translation type="unfinished"/>
+        <translation>Minun suosikit</translation>
     </message>
     <message>
         <location filename="../core/playlistmanager.cpp" line="147"/>
         <source>Search result</source>
-        <translation type="unfinished"/>
+        <translation>Hakutulokset</translation>
     </message>
 </context>
 <context>
@@ -475,15 +475,15 @@
     <message>
         <location filename="../view/playlistwidget.cpp" line="58"/>
         <source>New playlist</source>
-        <translation type="unfinished"/>
+        <translation>Uusi soittolista</translation>
     </message>
 </context>
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="../view/mainframe.cpp" line="255"/>
+        <location filename="../view/mainframe.cpp" line="256"/>
         <source>Deepin Music</source>
-        <translation>Deepin Musiikkitoistin</translation>
+        <translation>Deepin Musiikki</translation>
     </message>
 </context>
 <context>
@@ -491,37 +491,37 @@
     <message>
         <location filename="../main.cpp" line="87"/>
         <source>Deepin Music</source>
-        <translation>Deepin Music</translation>
+        <translation>Deepin Musiikki</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="26"/>
         <source>Minimize to system tray</source>
-        <translation type="unfinished"/>
+        <translation>Minimoi valikkoon</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="27"/>
         <source>Exit Deepin Music</source>
-        <translation type="unfinished"/>
+        <translation>Poistu Deepin musiikista</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="28"/>
         <source>Autoplay</source>
-        <translation type="unfinished"/>
+        <translation>Automaattitoisto</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="29"/>
-        <source>Enable fade</source>
-        <translation type="unfinished"/>
+        <source>Enable fade in/out</source>
+        <translation>Salli häivytys</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="30"/>
         <source>Remember playback position</source>
-        <translation type="unfinished"/>
+        <translation>Muista toiston sijainti</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="31"/>
         <source>Close Main Window</source>
-        <translation type="unfinished"/>
+        <translation>Sulje pääikkuna</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="32"/>
@@ -541,7 +541,7 @@
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="35"/>
         <source>Restore Defaults</source>
-        <translation>Palauta Oletusasetukset</translation>
+        <translation>Palauta oletukset</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="36"/>
@@ -575,7 +575,7 @@
         <location filename="../view/widget/searchresult.cpp" line="57"/>
         <location filename="../view/widget/searchresult.cpp" line="126"/>
         <source>Search &quot;%1&quot; in Deepin Music</source>
-        <translation type="unfinished"/>
+        <translation>Hae &quot;%1&quot; Deepin musiikista</translation>
     </message>
 </context>
 <context>
