@@ -4,7 +4,7 @@
     <message>
         <location filename="../view/widget/closeconfirmdialog.cpp" line="61"/>
         <source>Please select your operation</source>
-        <translation type="unfinished"/>
+        <translation>Үйлдлээ сонгоно уу</translation>
     </message>
     <message>
         <location filename="../view/widget/closeconfirmdialog.cpp" line="68"/>
@@ -14,11 +14,11 @@
     <message>
         <location filename="../view/widget/closeconfirmdialog.cpp" line="70"/>
         <source>Minimize to system tray</source>
-        <translation type="unfinished"/>
+        <translation>Систем мѳрѳнд шилжүүлэх</translation>
     </message>
     <message>
         <location filename="../view/widget/closeconfirmdialog.cpp" line="79"/>
-        <source>Never ask again</source>
+        <source>Do not ask again</source>
         <translation type="unfinished"/>
     </message>
     <message>
@@ -29,7 +29,7 @@
     <message>
         <location filename="../view/widget/closeconfirmdialog.cpp" line="91"/>
         <source>OK</source>
-        <translation type="unfinished"/>
+        <translation>ЗА</translation>
     </message>
 </context>
 <context>
@@ -37,7 +37,7 @@
     <message>
         <location filename="../view/footerwidget.cpp" line="290"/>
         <source>Previous</source>
-        <translation type="unfinished"/>
+        <translation>Ѳмнѳх</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="291"/>
@@ -47,54 +47,54 @@
     <message>
         <location filename="../view/footerwidget.cpp" line="292"/>
         <source>Play/Pause</source>
-        <translation type="unfinished"/>
+        <translation>Тоглуулах/Зогсоох</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="293"/>
         <source>Favorite</source>
-        <translation type="unfinished"/>
+        <translation>Дуртай</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="294"/>
         <source>Lyrics</source>
-        <translation type="unfinished"/>
+        <translation>Дууны үг</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="239"/>
         <source>Unknown Title</source>
-        <translation type="unfinished"/>
+        <translation>Тодорхойгүй нэр</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="245"/>
         <location filename="../view/footerwidget.cpp" line="536"/>
         <location filename="../view/footerwidget.cpp" line="718"/>
         <source>Unknown artist</source>
-        <translation type="unfinished"/>
+        <translation>Тодорхойгүй уран бүтээлч</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="295"/>
         <source>Play Mode</source>
-        <translation type="unfinished"/>
+        <translation>Тоглох горим</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="296"/>
         <source>Playlist</source>
-        <translation type="unfinished"/>
+        <translation>Жагсаалт</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="696"/>
         <source>List Loop</source>
-        <translation type="unfinished"/>
+        <translation>Давтах жагсаалт</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="699"/>
         <source>Single Loop</source>
-        <translation type="unfinished"/>
+        <translation>Нэгийг давт</translation>
     </message>
     <message>
         <location filename="../view/footerwidget.cpp" line="702"/>
         <source>Shuffle</source>
-        <translation type="unfinished"/>
+        <translation>Холих</translation>
     </message>
 </context>
 <context>
@@ -102,24 +102,24 @@
     <message>
         <location filename="../view/importwidget.cpp" line="73"/>
         <source>Add folder</source>
-        <translation type="unfinished"/>
+        <translation>Хавтас нэмэх</translation>
     </message>
     <message>
         <location filename="../view/importwidget.cpp" line="79"/>
         <location filename="../view/importwidget.cpp" line="120"/>
         <source>Scan</source>
-        <translation type="unfinished"/>
+        <translation>Шүүх</translation>
     </message>
     <message>
         <location filename="../view/importwidget.cpp" line="80"/>
         <location filename="../view/importwidget.cpp" line="121"/>
         <source>%1 music directory or drag &amp; drop music file to add music</source>
-        <translation type="unfinished"/>
+        <translation>%1 хавтас эсвэл дуугаа чирч оруулна уу</translation>
     </message>
     <message>
         <location filename="../view/importwidget.cpp" line="112"/>
         <source>Loading music, please wait...</source>
-        <translation type="unfinished"/>
+        <translation>Уншиж байна, түр хүлээнэ үү...</translation>
     </message>
 </context>
 <context>
@@ -127,47 +127,47 @@
     <message>
         <location filename="../view/widget/infodialog.cpp" line="117"/>
         <source>Title:</source>
-        <translation type="unfinished"/>
+        <translation>Гарчиг:</translation>
     </message>
     <message>
         <location filename="../view/widget/infodialog.cpp" line="117"/>
         <source>Artist:</source>
-        <translation type="unfinished"/>
+        <translation>Уран бүтээлч:</translation>
     </message>
     <message>
         <location filename="../view/widget/infodialog.cpp" line="118"/>
         <source>Album:</source>
-        <translation type="unfinished"/>
+        <translation>Цомог:</translation>
     </message>
     <message>
         <location filename="../view/widget/infodialog.cpp" line="118"/>
         <source>Type:</source>
-        <translation type="unfinished"/>
+        <translation>Тѳрѳл:</translation>
     </message>
     <message>
         <location filename="../view/widget/infodialog.cpp" line="120"/>
         <source>Path:</source>
-        <translation type="unfinished"/>
+        <translation>Зам:</translation>
     </message>
     <message>
         <location filename="../view/widget/infodialog.cpp" line="192"/>
         <source>Unknown artist</source>
-        <translation type="unfinished"/>
+        <translation>Тодорхойгүй уран бүтээлч</translation>
     </message>
     <message>
         <location filename="../view/widget/infodialog.cpp" line="193"/>
         <source>Unknown album</source>
-        <translation type="unfinished"/>
+        <translation>Тодорхойгүй цомог</translation>
     </message>
     <message>
         <location filename="../view/widget/infodialog.cpp" line="119"/>
         <source>Size:</source>
-        <translation type="unfinished"/>
+        <translation>Хэмжээ:</translation>
     </message>
     <message>
         <location filename="../view/widget/infodialog.cpp" line="119"/>
         <source>Duration:</source>
-        <translation type="unfinished"/>
+        <translation>Үргэлжлэх хугацаа:</translation>
     </message>
 </context>
 <context>
@@ -175,25 +175,25 @@
     <message>
         <location filename="../view/loadwidget.cpp" line="43"/>
         <source>Loading...</source>
-        <translation type="unfinished"/>
+        <translation>Уншиж байна...</translation>
     </message>
 </context>
 <context>
     <name>LyricWidget</name>
     <message>
         <location filename="../view/lyricwidget.cpp" line="166"/>
-        <source>Search lyrics</source>
+        <source>Find lyrics</source>
         <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../view/lyricwidget.cpp" line="170"/>
         <source>Title</source>
-        <translation type="unfinished"/>
+        <translation>Гарчиг</translation>
     </message>
     <message>
         <location filename="../view/lyricwidget.cpp" line="175"/>
         <source>Artist</source>
-        <translation type="unfinished"/>
+        <translation>Уран бүтээлч</translation>
     </message>
     <message>
         <location filename="../view/lyricwidget.cpp" line="180"/>
@@ -203,85 +203,85 @@
     <message>
         <location filename="../view/lyricwidget.cpp" line="213"/>
         <source>Back</source>
-        <translation type="unfinished"/>
+        <translation>Буцах</translation>
     </message>
 </context>
 <context>
     <name>MainFrame</name>
     <message>
-        <location filename="../view/mainframe.cpp" line="135"/>
+        <location filename="../view/mainframe.cpp" line="136"/>
         <source>New playlist</source>
-        <translation type="unfinished"/>
+        <translation>Шинэ жагсаалт</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="151"/>
+        <location filename="../view/mainframe.cpp" line="152"/>
         <source>Settings</source>
-        <translation type="unfinished"/>
+        <translation>Тохиргоо</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="253"/>
-        <source>Deepin Music Player is a local  music player with beautiful design and simple functions. It supports viewing lyrics when playing, playing lossless music and customize playlist, etc.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/mainframe.cpp" line="182"/>
-        <location filename="../view/mainframe.cpp" line="578"/>
+        <location filename="../view/mainframe.cpp" line="183"/>
+        <location filename="../view/mainframe.cpp" line="595"/>
         <source>Exit</source>
         <translation>Гарах</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="141"/>
+        <location filename="../view/mainframe.cpp" line="142"/>
         <source>Add folder</source>
-        <translation type="unfinished"/>
+        <translation>Хавтас нэмэх</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="146"/>
+        <location filename="../view/mainframe.cpp" line="147"/>
         <source>Add file</source>
-        <translation type="unfinished"/>
+        <translation>Файл нэмэх</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="167"/>
+        <location filename="../view/mainframe.cpp" line="168"/>
         <source>Dark theme</source>
+        <translation>Бараан загвар</translation>
+    </message>
+    <message>
+        <location filename="../view/mainframe.cpp" line="254"/>
+        <source>Deepin Music is a beautiful and simple music player that plays local audios. It supports viewing lyrics during playback, playing lossless audio and playlist customization, etc.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="575"/>
+        <location filename="../view/mainframe.cpp" line="592"/>
         <source>Play/Pause</source>
-        <translation type="unfinished"/>
+        <translation>Тоглуулах/Зогсоох</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="576"/>
+        <location filename="../view/mainframe.cpp" line="593"/>
         <source>Previous</source>
-        <translation type="unfinished"/>
+        <translation>Ѳмнѳх</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="722"/>
+        <location filename="../view/mainframe.cpp" line="739"/>
         <source>Invalid or non-existent file</source>
-        <translation type="unfinished"/>
+        <translation>Алдаатай эсвэл байхгүй файл</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="743"/>
+        <location filename="../view/mainframe.cpp" line="760"/>
         <source>Failed to import, no vaild music file found!</source>
-        <translation type="unfinished"/>
+        <translation>Импортолж чадсангүй, хөгжмийн файл олдсонгүй!</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="1018"/>
+        <location filename="../view/mainframe.cpp" line="1027"/>
         <source>All music</source>
-        <translation type="unfinished"/>
+        <translation>Бүх хѳгжим</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="723"/>
-        <location filename="../view/mainframe.cpp" line="748"/>
+        <location filename="../view/mainframe.cpp" line="740"/>
+        <location filename="../view/mainframe.cpp" line="765"/>
         <source>OK</source>
-        <translation type="unfinished"/>
+        <translation>ЗА</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="673"/>
+        <location filename="../view/mainframe.cpp" line="690"/>
         <source>Successfully added to &quot;%1&quot;</source>
-        <translation type="unfinished"/>
+        <translation>&quot;%1&quot; амжилттай нэмлээ</translation>
     </message>
     <message>
-        <location filename="../view/mainframe.cpp" line="577"/>
+        <location filename="../view/mainframe.cpp" line="594"/>
         <source>Next</source>
         <translation>Дараах</translation>
     </message>
@@ -289,80 +289,80 @@
 <context>
     <name>MusicListView</name>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="287"/>
+        <location filename="../view/widget/musiclistview.cpp" line="295"/>
         <source>New playlist</source>
-        <translation type="unfinished"/>
+        <translation>Шинэ жагсаалт</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="327"/>
+        <location filename="../view/widget/musiclistview.cpp" line="335"/>
         <source>Play</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/widget/musiclistview.cpp" line="329"/>
-        <source>Add to playlist</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/widget/musiclistview.cpp" line="334"/>
-        <source>Display in file manager</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/widget/musiclistview.cpp" line="361"/>
-        <source>Song info</source>
-        <translation type="unfinished"/>
+        <translation>Тоглуулах</translation>
     </message>
     <message>
         <location filename="../view/widget/musiclistview.cpp" line="337"/>
+        <source>Add to playlist</source>
+        <translation>Жагсаалтад нэмэх</translation>
+    </message>
+    <message>
+        <location filename="../view/widget/musiclistview.cpp" line="342"/>
+        <source>Display in file manager</source>
+        <translation>Файл менежерт харах</translation>
+    </message>
+    <message>
+        <location filename="../view/widget/musiclistview.cpp" line="369"/>
+        <source>Song info</source>
+        <translation>Дууны мэдээлэл</translation>
+    </message>
+    <message>
+        <location filename="../view/widget/musiclistview.cpp" line="425"/>
+        <source>Are you sure you want to delete %1?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../view/widget/musiclistview.cpp" line="427"/>
+        <location filename="../view/widget/musiclistview.cpp" line="431"/>
+        <source>Are you sure you want to delete the selected %1 songs?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../view/widget/musiclistview.cpp" line="345"/>
         <source>Remove from playlist</source>
-        <translation type="unfinished"/>
+        <translation>Жагсаалтаас хасах</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="338"/>
+        <location filename="../view/widget/musiclistview.cpp" line="346"/>
         <source>Delete from local disk</source>
-        <translation type="unfinished"/>
+        <translation>Ѳѳр дээрээс устгах</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="357"/>
+        <location filename="../view/widget/musiclistview.cpp" line="365"/>
         <source>Encoding</source>
-        <translation type="unfinished"/>
+        <translation>Энкод</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="407"/>
+        <location filename="../view/widget/musiclistview.cpp" line="415"/>
         <source>Cancel</source>
         <translation>Цуцлах</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="408"/>
+        <location filename="../view/widget/musiclistview.cpp" line="416"/>
         <source>Delete</source>
         <translation>Устгах</translation>
     </message>
     <message>
-        <location filename="../view/widget/musiclistview.cpp" line="417"/>
-        <source>Are you sure to delete %1?</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/widget/musiclistview.cpp" line="419"/>
-        <location filename="../view/widget/musiclistview.cpp" line="423"/>
-        <source>Are you sure to delete the selected %1 songs?</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/widget/musiclistview.cpp" line="424"/>
+        <location filename="../view/widget/musiclistview.cpp" line="432"/>
         <source>Deleting the current song will also delete the song files contained</source>
-        <translation type="unfinished"/>
+        <translation>Энэ дууг устгаснаар хадгалагдаж буй файл устгагдана</translation>
     </message>
     <message>
         <location filename="../view/widget/delegate/musicitemdelegate.cpp" line="299"/>
         <source>Unknown artist</source>
-        <translation type="unfinished"/>
+        <translation>Тодорхойгүй уран бүтээлч</translation>
     </message>
     <message>
         <location filename="../view/widget/delegate/musicitemdelegate.cpp" line="310"/>
         <source>Unknown album</source>
-        <translation type="unfinished"/>
+        <translation>Тодорхойгүй цомог</translation>
     </message>
 </context>
 <context>
@@ -370,58 +370,58 @@
     <message>
         <location filename="../view/musiclistwidget.cpp" line="140"/>
         <source>No Music</source>
-        <translation type="unfinished"/>
+        <translation>Дуу алга</translation>
     </message>
     <message>
         <location filename="../view/musiclistwidget.cpp" line="142"/>
         <source>No result found</source>
-        <translation type="unfinished"/>
+        <translation>Үр дүн олдсонгүй</translation>
     </message>
     <message>
         <location filename="../view/musiclistwidget.cpp" line="174"/>
         <source>Play All</source>
-        <translation type="unfinished"/>
+        <translation>Бүгдийг тоглуул</translation>
     </message>
     <message>
         <location filename="../view/musiclistwidget.cpp" line="182"/>
         <source>Time added</source>
-        <translation type="unfinished"/>
+        <translation>Нэмсэн огноо</translation>
     </message>
     <message>
         <location filename="../view/musiclistwidget.cpp" line="183"/>
         <source>Title</source>
-        <translation type="unfinished"/>
+        <translation>Гарчиг</translation>
     </message>
     <message>
         <location filename="../view/musiclistwidget.cpp" line="184"/>
         <source>Artist</source>
-        <translation type="unfinished"/>
+        <translation>Уран бүтээлч</translation>
     </message>
     <message>
         <location filename="../view/musiclistwidget.cpp" line="185"/>
         <source>Album name</source>
-        <translation type="unfinished"/>
+        <translation>Цомгийн нэр</translation>
     </message>
     <message>
         <location filename="../view/musiclistwidget.cpp" line="217"/>
         <source>Custom</source>
-        <translation type="unfinished"/>
+        <translation>Дурын</translation>
     </message>
 </context>
 <context>
     <name>PlayListItem</name>
     <message>
-        <location filename="../view/widget/playlistitem.cpp" line="193"/>
+        <location filename="../view/widget/playlistitem.cpp" line="187"/>
+        <source>Are you sure you want to delete this playlist?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../view/widget/playlistitem.cpp" line="194"/>
         <source>Delete</source>
         <translation>Устгах</translation>
     </message>
     <message>
-        <location filename="../view/widget/playlistitem.cpp" line="186"/>
-        <source>Are you sure to delete this playlist?</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../view/widget/playlistitem.cpp" line="192"/>
+        <location filename="../view/widget/playlistitem.cpp" line="193"/>
         <source>Cancel</source>
         <translation>Цуцлах</translation>
     </message>
@@ -432,13 +432,13 @@
         <location filename="../view/widget/playlistview.cpp" line="186"/>
         <location filename="../view/widget/playlistview.cpp" line="195"/>
         <source>Play</source>
-        <translation type="unfinished"/>
+        <translation>Тоглуулах</translation>
     </message>
     <message>
         <location filename="../view/widget/playlistview.cpp" line="190"/>
         <location filename="../view/widget/playlistview.cpp" line="198"/>
         <source>Rename</source>
-        <translation type="unfinished"/>
+        <translation>Дахин нэрлэх</translation>
     </message>
     <message>
         <location filename="../view/widget/playlistview.cpp" line="191"/>
@@ -452,22 +452,22 @@
     <message>
         <location filename="../core/playlistmanager.cpp" line="79"/>
         <source>New playlist</source>
-        <translation type="unfinished"/>
+        <translation>Шинэ жагсаалт</translation>
     </message>
     <message>
         <location filename="../core/playlistmanager.cpp" line="135"/>
         <source>All Music</source>
-        <translation type="unfinished"/>
+        <translation>Бүх хѳгжим</translation>
     </message>
     <message>
         <location filename="../core/playlistmanager.cpp" line="141"/>
         <source>My favorites</source>
-        <translation type="unfinished"/>
+        <translation>Дуртай</translation>
     </message>
     <message>
         <location filename="../core/playlistmanager.cpp" line="147"/>
         <source>Search result</source>
-        <translation type="unfinished"/>
+        <translation>Хайлтын үр дүн</translation>
     </message>
 </context>
 <context>
@@ -475,15 +475,15 @@
     <message>
         <location filename="../view/playlistwidget.cpp" line="58"/>
         <source>New playlist</source>
-        <translation type="unfinished"/>
+        <translation>Шинэ жагсаалт</translation>
     </message>
 </context>
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="../view/mainframe.cpp" line="255"/>
+        <location filename="../view/mainframe.cpp" line="256"/>
         <source>Deepin Music</source>
-        <translation type="unfinished"/>
+        <translation>Дээпин хөгжим</translation>
     </message>
 </context>
 <context>
@@ -491,57 +491,57 @@
     <message>
         <location filename="../main.cpp" line="87"/>
         <source>Deepin Music</source>
-        <translation type="unfinished"/>
+        <translation>Дээпин Хѳгжи</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="26"/>
         <source>Minimize to system tray</source>
-        <translation type="unfinished"/>
+        <translation>Систем мѳрѳнд шилжүүлэх</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="27"/>
         <source>Exit Deepin Music</source>
-        <translation type="unfinished"/>
+        <translation>Дээпин хѳгжим гаргах</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="28"/>
         <source>Autoplay</source>
-        <translation type="unfinished"/>
+        <translation>Тоглуул</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="29"/>
-        <source>Enable fade</source>
+        <source>Enable fade in/out</source>
         <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="30"/>
         <source>Remember playback position</source>
-        <translation type="unfinished"/>
+        <translation>Тоглуулах байрлалыг санах</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="31"/>
         <source>Close Main Window</source>
-        <translation type="unfinished"/>
+        <translation>Үндсэн цонхыг хаах</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="32"/>
         <source>Basic</source>
-        <translation type="unfinished"/>
+        <translation>Энгийн</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="33"/>
         <source>Play</source>
-        <translation type="unfinished"/>
+        <translation>Тоглуулах</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="34"/>
         <source>Shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Товчнууд</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="35"/>
         <source>Restore Defaults</source>
-        <translation type="unfinished"/>
+        <translation>Анхдагч утга сэргээх</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="36"/>
@@ -551,22 +551,22 @@
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="37"/>
         <source>Play/Pause</source>
-        <translation type="unfinished"/>
+        <translation>Тоглуулах/Зогсоох</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="38"/>
         <source>Previous</source>
-        <translation type="unfinished"/>
+        <translation>Ѳмнѳх</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="39"/>
         <source>Volume down</source>
-        <translation type="unfinished"/>
+        <translation>Дуу намсгах</translation>
     </message>
     <message>
         <location filename="../view/widget/settingsdialog.cpp" line="40"/>
         <source>Volume up</source>
-        <translation type="unfinished"/>
+        <translation>Дуу чангалах</translation>
     </message>
 </context>
 <context>
@@ -575,7 +575,7 @@
         <location filename="../view/widget/searchresult.cpp" line="57"/>
         <location filename="../view/widget/searchresult.cpp" line="126"/>
         <source>Search &quot;%1&quot; in Deepin Music</source>
-        <translation type="unfinished"/>
+        <translation>Деепин хөгжимөөс &quot;%1&quot; хайх</translation>
     </message>
 </context>
 <context>
