@@ -95,6 +95,7 @@ public:
     void updateViewname(const QString &vm);
     void updateTitlebarViewname(const QString &vm);
     void overrideTitlebarStyle();
+    const QString getLastImportPath() const;
 
     //! ui: show info dialog
     void showInfoDialog(const MetaPtr meta);
@@ -250,7 +251,7 @@ void MainFramePrivate::postInitUI()
 {
     Q_Q(MainFrame);
 
-    QString descriptionText = MainFrame::tr("Deepin Music Player is a local  music player with beautiful design and simple functions. It supports viewing lyrics when playing, playing lossless music and customize playlist, etc.");
+    QString descriptionText = MainFrame::tr("Deepin Music is a beautiful and simple music player that plays local audios. It supports viewing lyrics during playback, playing lossless audio and playlist customization, etc.");
     QString acknowledgementLink = "https://www.deepin.org/acknowledgments/deepin-music#thanks";
     qApp->setProductName(QApplication::tr("Deepin Music"));
     qApp->setApplicationAcknowledgementPage(acknowledgementLink);
@@ -539,6 +540,22 @@ void MainFramePrivate::overrideTitlebarStyle()
     }
 }
 
+const QString MainFramePrivate::getLastImportPath() const
+{
+    QString lastImportPath = MusicSettings::value("base.play.last_import_path").toString();
+
+    QDir lastImportDir = QDir(lastImportPath);
+    if (!lastImportDir.exists() || lastImportPath.isEmpty()) {
+        lastImportPath =  QStandardPaths::standardLocations(QStandardPaths::MusicLocation).first();
+    } else {
+        // blumia: always use the path from QDir, QDir also accept relative path string and it will pass
+        //         the `QDir::exists()` checking
+        lastImportPath = lastImportDir.absolutePath();
+    }
+
+    return lastImportPath;
+}
+
 void MainFramePrivate::showInfoDialog(const MetaPtr meta)
 {
     infoDialog->show();
@@ -636,12 +653,12 @@ void MainFrame::binding(Presenter *presenter)
 
 #ifdef Q_OS_WIN
     connect(d->titlebar, &Titlebar::mousePosMoving,
-    this, [ = ](Qt::MouseButton /*botton*/, QPoint pos) {
+    this, [ = ](Qt::MouseButton /*button*/, QPoint pos) {
         move(pos - d->m_LastMousePos);
     });
 
     connect(d->titlebar, &Titlebar::mousePosPressed,
-    this, [ = ](Qt::MouseButtons /*botton*/, QPoint pos) {
+    this, [ = ](Qt::MouseButtons /*button*/, QPoint pos) {
         // TODO: fix margin
         pos.setY(pos.y() - 10);
         d->m_LastMousePos = pos - this->mapToParent(this->pos());
@@ -985,16 +1002,7 @@ void MainFrame::onSelectImportDirectory()
     Q_D(const MainFrame);
     QFileDialog fileDlg(this);
 
-    auto lastImportPath = MusicSettings::value("base.play.last_import_path").toString();
-
-    QDir lastImportDir = QDir(lastImportPath);
-    if (!lastImportDir.exists() || lastImportPath.isEmpty()) {
-        lastImportPath =  QStandardPaths::standardLocations(QStandardPaths::MusicLocation).first();
-    } else {
-        // blumia: always use the path from QDir, QDir also accept relative path string and it will pass
-        //         the `QDir::exists()` checking
-        lastImportPath = lastImportDir.absolutePath();
-    }
+    QString lastImportPath = d->getLastImportPath();
 
     fileDlg.setDirectory(lastImportPath);
 
@@ -1012,12 +1020,8 @@ void MainFrame::onSelectImportFiles()
     Q_D(const MainFrame);
     QFileDialog fileDlg(this);
 
-    auto lastImportPath = MusicSettings::value("base.play.last_import_path").toString();
+    QString lastImportPath = d->getLastImportPath();
 
-    auto lastImportDir = QDir(lastImportPath);
-    if (!lastImportDir.exists()) {
-        lastImportPath =  QStandardPaths::standardLocations(QStandardPaths::MusicLocation).first();
-    }
     fileDlg.setDirectory(lastImportPath);
 
     QString selfilter = tr("All music") + (" (%1)");
